@@ -28,7 +28,7 @@ class TranslateContext(object):
         text = u''.join(self.text).strip()
         text = self.WHITESPACE.sub(u' ', text)
         text = self.EXPRESSION.sub(u'', text)
-        return not text 
+        return not text
 
     def message(self):
         text = u''.join(self.text).strip()
@@ -58,7 +58,7 @@ class XmlExtractor(object):
         self.parser.DefaultHandler = self.DefaultHandler
         self.domainstack = collections.deque()
         self.translatestack = collections.deque([None])
-        self.prefix_stack = collections.deque([None])
+        self.prefix_stack = collections.deque(['i18n'])
 
         try:
             self.parser.ParseFile(fileobj)
